@@ -1,6 +1,6 @@
 
 from cubicweb.predicates import match_form_params
-from cubicweb.web.views import basecontrollers
+from cubicweb_web.views import basecontrollers
 
 
 class CardViewController(basecontrollers.ViewController):
