@@ -6,7 +6,7 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.web.views.urlrewrite import SchemaBasedRewriter, rgx, rgx_action
+from cubicweb_web.views.urlrewrite import SchemaBasedRewriter, rgx, rgx_action
 
 
 class CardURLRewriter(SchemaBasedRewriter):
